==> haskell-text-zipper-0.13-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-46vFMWenJDpClisUQfAfbu
key:                  text-zipper-0.13-46vFMWenJDpClisUQfAfbu
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  2ad983a050726cd4886fee0842b2cb34
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-46vFMWenJDpClisUQfAfbu
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.13-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-zipper
version:              0.13
visibility:           public
id:                   text-zipper-0.13-AysX7IsPKfPEfIp1nGtEBK
key:                  text-zipper-0.13-AysX7IsPKfPEfIp1nGtEBK
license:              BSD-3-Clause
copyright:            (c) 2015 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/text-zipper/
synopsis:             A text editor zipper library
description:          This library provides a zipper and API for editing text.
category:             Text
abi:                  4de7909120c2f7395f9ce14614dc5e77
exposed:              True
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words

hidden-modules:       Data.Text.Zipper.Vector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-zipper-0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-zipper
hs-libraries:         HStext-zipper-0.13-AysX7IsPKfPEfIp1nGtEBK
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-HGgKaKiJszd4ty04a0OkB8

haddock-interfaces:   /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html:         /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
